==> pandoc-crossref-0.3.0.0-10-armv7h.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.3.0.0
id: pandoc-crossref-0.3.0.0-AKeYeejjSXJJNl3MoSfhJY
key: pandoc-crossref-0.3.0.0-AKeYeejjSXJJNl3MoSfhJY
license: GPL
maintainer: root@livid.pp.ru
homepage: https://github.com/lierdakil/pandoc-crossref#readme
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
indefinite: False
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.PandocOrphans
                Text.Pandoc.CrossRef.Util.Settings
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Paths_pandoc_crossref
abi: f90520f91b2c5a9b9857e9c4a2486aeb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pandoc-crossref-0.3.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/pandoc-crossref-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.3.0.0-AKeYeejjSXJJNl3MoSfhJY
depends:
    base-4.10.1.0 containers-0.5.10.2
    data-accessor-0.2.2.7-4CrRvEdxlxZ5TbrmuBHi6H
    data-accessor-template-0.2.1.14-6gt9LGgX0RmEaq7hsXwZaf
    data-accessor-transformers-0.2.1.7-I2gusl5R6182OQTxkE2Wir
    data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65 directory-1.3.0.2
    filepath-1.4.1.2 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    pandoc-2.0.6-cnexmh5pdzE7KWcBMsIlo
    pandoc-types-1.17.3-8GppY48mAIrAbgJesaAZW6
    roman-numerals-0.5.1.5-ARheSnyRO53Fu09gKbBK7n
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0 template-haskell-2.12.0.0
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             data-accessor-0.2.2.7-4CrRvEdxlxZ5TbrmuBHi6H=69f7b4517dfcc0e49f92b8cf9762b41d
             data-accessor-template-0.2.1.14-6gt9LGgX0RmEaq7hsXwZaf=8b53fd8c6bfcb5d938b2a5e60a56374f
             data-accessor-transformers-0.2.1.7-I2gusl5R6182OQTxkE2Wir=7a528345654e9689facb69310cbad610
             data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65=f057e993f72fa1f980dd728ed8010ca1
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             pandoc-2.0.6-cnexmh5pdzE7KWcBMsIlo=13458750791670b494070201e29ae72c
             pandoc-types-1.17.3-8GppY48mAIrAbgJesaAZW6=2b3ba4eded2d2e303cecf9da1e35f465
             roman-numerals-0.5.1.5-ARheSnyRO53Fu09gKbBK7n=ef45e39be436eb9a57cf28db0e2e28cd
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.3.0.0-15-armv7h.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.3.0.0
id: pandoc-crossref-0.3.0.0-Iek0Ew2GjOGKf73Su5UZbl
key: pandoc-crossref-0.3.0.0-Iek0Ew2GjOGKf73Su5UZbl
license: GPL
maintainer: root@livid.pp.ru
homepage: https://github.com/lierdakil/pandoc-crossref#readme
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
indefinite: False
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.PandocOrphans
                Text.Pandoc.CrossRef.Util.Settings
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Paths_pandoc_crossref
abi: b7fb1318a4bdfea47eae170047e8dc1e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pandoc-crossref-0.3.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/pandoc-crossref-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.3.0.0-Iek0Ew2GjOGKf73Su5UZbl
depends:
    base-4.10.1.0 containers-0.5.10.2
    data-accessor-0.2.2.7-4CrRvEdxlxZ5TbrmuBHi6H
    data-accessor-template-0.2.1.14-6gt9LGgX0RmEaq7hsXwZaf
    data-accessor-transformers-0.2.1.7-I2gusl5R6182OQTxkE2Wir
    data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65 directory-1.3.0.2
    filepath-1.4.1.2 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    pandoc-2.0.6-BOTgIYGEbOl2HWbVi1KFP7
    pandoc-types-1.17.3-8GppY48mAIrAbgJesaAZW6
    roman-numerals-0.5.1.5-ARheSnyRO53Fu09gKbBK7n
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0 template-haskell-2.12.0.0
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             data-accessor-0.2.2.7-4CrRvEdxlxZ5TbrmuBHi6H=69f7b4517dfcc0e49f92b8cf9762b41d
             data-accessor-template-0.2.1.14-6gt9LGgX0RmEaq7hsXwZaf=8b53fd8c6bfcb5d938b2a5e60a56374f
             data-accessor-transformers-0.2.1.7-I2gusl5R6182OQTxkE2Wir=7a528345654e9689facb69310cbad610
             data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65=f057e993f72fa1f980dd728ed8010ca1
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             pandoc-2.0.6-BOTgIYGEbOl2HWbVi1KFP7=e122dd4f9d4bc26162b958fe43473ab5
             pandoc-types-1.17.3-8GppY48mAIrAbgJesaAZW6=2b3ba4eded2d2e303cecf9da1e35f465
             roman-numerals-0.5.1.5-ARheSnyRO53Fu09gKbBK7n=ef45e39be436eb9a57cf28db0e2e28cd
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
